#Requires -RunAsAdministrator

param(
    [string]$DVLS_SERVER_URL
)

try {
    $appDataPath = [System.Environment]::GetFolderPath('ApplicationData');
    $configFilePath = Join-Path $appDataPath 'net.devolutions\\Workspace\\Config.cfg';
    $logPath = Join-Path $appDataPath 'net.devolutions\\Workspace\\CreateConfigLog.txt';

    if (-not (Test-Path (Split-Path $configFilePath))) {
        New-Item -Path (Split-Path $configFilePath) -ItemType Directory -Force;
    }

    Add-Content -Path $logPath -Value 'Starting config file creation...';

    $configContent = @{
        hubs = @();
        dvls = @(
            @{
                name = 'Devolutions Server';
                serverUrl = $DVLS_SERVER_URL;
                serverVersion = '2024.3.0.0';
            }
        );
        preventStartup = $true;
    };

    $json = $configContent | ConvertTo-Json -Compress;
    Add-Content -Path $logPath -Value "Config content created: $json";

    Set-Content -Path $configFilePath -Value $json;

    Add-Content -Path $logPath -Value "Config file created successfully at $configFilePath";
}
catch {
    Add-Content -Path $logPath -Value "Error creating config file: $_";
    exit 1;
}
